// src/environment/load-env.ts
import { join } from "node:path";

// src/terminal/ascii.ts
import { magentaBright } from "yoctocolors";

// src/logging/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
import { inverse, redBright } from "yoctocolors";
var CancelError = class extends Error {
};
var cancel = (msg) => {
  console.log("");
  console.log(inverse(redBright(maskTokens(msg))));
  console.log("");
  throw new CancelError(msg);
};

// src/terminal/execute-command.ts
import { spawn } from "node:child_process";

// src/terminal/intro.ts
import { magentaBright as magentaBright2 } from "yoctocolors";

// src/terminal/note.ts
import { yellowBright } from "yoctocolors";

// src/terminal/outro.ts
import { greenBright, inverse as inverse2 } from "yoctocolors";

// src/terminal/spinner.ts
import isInCi from "is-in-ci";
import yoctoSpinner from "yocto-spinner";
import { redBright as redBright2 } from "yoctocolors";

// src/terminal/table.ts
import { Table } from "console-table-printer";
import { whiteBright } from "yoctocolors";

// src/validation/validate.ts
import { ZodError } from "zod";
function validate(schema, value) {
  try {
    return schema.parse(value);
  } catch (error) {
    if (error instanceof ZodError) {
      const formattedErrors = error.errors.map((err) => `- ${err.path.join(".")}: ${err.message}`).join("\n");
      throw new Error(`Validation error${error.errors.length > 1 ? "s" : ""}:
${formattedErrors}`);
    }
    throw error;
  }
}

// src/validation/access-token.schema.ts
import { z } from "zod";
var ApplicationAccessTokenSchema = z.string().regex(/^sm_aat_.*$/);
var PersonalAccessTokenSchema = z.string().regex(/^sm_pat_.*$/);
var AccessTokenSchema = z.string().regex(/^sm_pat_.*|sm_aat_.*$/);

// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/validation/dot-env.schema.ts
import { z as z4 } from "zod";

// src/validation/unique-name.schema.ts
import { z as z2 } from "zod";
var UniqueNameSchema = z2.string().regex(/^[a-z0-9-]+$/);

// src/validation/url.schema.ts
import { z as z3 } from "zod";
var UrlSchema = z3.string().url();
var UrlPathSchema = z3.string().regex(/^\/(?:[a-zA-Z0-9-_]+(?:\/[a-zA-Z0-9-_]+)*\/?)?$/, {
  message: "Invalid URL path format. Must start with '/' and can contain letters, numbers, hyphens, and underscores."
});
var UrlOrPathSchema = z3.union([UrlSchema, UrlPathSchema]);

// src/validation/dot-env.schema.ts
var DotEnvSchema = z4.object({
  /** Base URL of the SettleMint platform instance */
  SETTLEMINT_INSTANCE: UrlSchema.default("https://console.settlemint.com"),
  /** Application access token for authenticating with SettleMint services */
  SETTLEMINT_ACCESS_TOKEN: ApplicationAccessTokenSchema.optional(),
  /** @internal */
  SETTLEMINT_PERSONAL_ACCESS_TOKEN: PersonalAccessTokenSchema.optional(),
  /** Unique name of the workspace */
  SETTLEMINT_WORKSPACE: UniqueNameSchema.optional(),
  /** Unique name of the application */
  SETTLEMINT_APPLICATION: UniqueNameSchema.optional(),
  /** Unique name of the blockchain network */
  SETTLEMINT_BLOCKCHAIN_NETWORK: UniqueNameSchema.optional(),
  /** Unique name of the blockchain node */
  SETTLEMINT_BLOCKCHAIN_NODE: UniqueNameSchema.optional(),
  /** Unique name of the load balancer */
  SETTLEMINT_LOAD_BALANCER: UniqueNameSchema.optional(),
  /** Unique name of the Hasura instance */
  SETTLEMINT_HASURA: UniqueNameSchema.optional(),
  /** Endpoint URL for the Hasura GraphQL API */
  SETTLEMINT_HASURA_ENDPOINT: UrlSchema.optional(),
  /** Admin secret for authenticating with Hasura */
  SETTLEMINT_HASURA_ADMIN_SECRET: z4.string().optional(),
  /** Database connection URL for Hasura */
  SETTLEMINT_HASURA_DATABASE_URL: z4.string().optional(),
  /** Unique name of The Graph instance */
  SETTLEMINT_THEGRAPH: UniqueNameSchema.optional(),
  /** Array of endpoint URLs for The Graph subgraphs */
  SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS: z4.preprocess(
    (value) => tryParseJson(value, []),
    z4.array(UrlSchema).optional()
  ),
  /** Default The Graph subgraph to use */
  SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH: z4.string().optional(),
  /** Unique name of the Smart Contract Portal instance */
  SETTLEMINT_PORTAL: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for the Portal */
  SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** REST endpoint URL for the Portal */
  SETTLEMINT_PORTAL_REST_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the HD private key */
  SETTLEMINT_HD_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the accessible private key */
  SETTLEMINT_ACCESSIBLE_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the MinIO instance */
  SETTLEMINT_MINIO: UniqueNameSchema.optional(),
  /** Endpoint URL for MinIO */
  SETTLEMINT_MINIO_ENDPOINT: UrlSchema.optional(),
  /** Access key for MinIO authentication */
  SETTLEMINT_MINIO_ACCESS_KEY: z4.string().optional(),
  /** Secret key for MinIO authentication */
  SETTLEMINT_MINIO_SECRET_KEY: z4.string().optional(),
  /** Unique name of the IPFS instance */
  SETTLEMINT_IPFS: UniqueNameSchema.optional(),
  /** API endpoint URL for IPFS */
  SETTLEMINT_IPFS_API_ENDPOINT: UrlSchema.optional(),
  /** Pinning service endpoint URL for IPFS */
  SETTLEMINT_IPFS_PINNING_ENDPOINT: UrlSchema.optional(),
  /** Gateway endpoint URL for IPFS */
  SETTLEMINT_IPFS_GATEWAY_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT: UniqueNameSchema.optional(),
  /** Endpoint URL for the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the Blockscout instance */
  SETTLEMINT_BLOCKSCOUT: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** UI endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT: UrlSchema.optional(),
  /** Name of the new project being created */
  SETTLEMINT_NEW_PROJECT_NAME: z4.string().optional(),
  /** The log level to use */
  SETTLEMINT_LOG_LEVEL: z4.enum(["debug", "info", "warn", "error", "none"]).default("warn")
});
var DotEnvSchemaPartial = DotEnvSchema.partial();

// src/validation/id.schema.ts
import { z as z5 } from "zod";
var IdSchema = z5.union([
  z5.string().uuid(),
  // PostgreSQL UUID
  z5.string().regex(/^[0-9a-fA-F]{24}$/)
  // MongoDB ObjectID
]);

// src/environment/load-env.ts
import { config } from "@dotenvx/dotenvx";
async function loadEnv(validateEnv, prod, path = process.cwd()) {
  return loadEnvironmentEnv(validateEnv, !!prod, path);
}
async function loadEnvironmentEnv(validateEnv, prod, path = process.cwd()) {
  if (prod) {
    process.env.NODE_ENV = "production";
  }
  let { parsed } = config({
    convention: "nextjs",
    logLevel: "error",
    overload: true,
    quiet: true,
    path: [join(path, ".env"), join(path, ".env.local")]
  });
  if (!parsed) {
    parsed = {};
  }
  const defaultEnv = Object.fromEntries(
    Object.entries(process.env).filter(([_, value]) => typeof value === "string" && value !== "")
  );
  try {
    return validate(validateEnv ? DotEnvSchema : DotEnvSchemaPartial, {
      ...parsed,
      ...defaultEnv
    });
  } catch (error) {
    cancel(error.message);
    return {};
  }
}

// src/environment/write-env.ts
import { writeFile } from "node:fs/promises";
import { join as join3 } from "node:path";

// src/filesystem/project-root.ts
import { dirname } from "node:path";
import { findUp } from "find-up";
async function projectRoot(fallbackToCwd = false, cwd) {
  const packageJsonPath = await findUp("package.json", { cwd });
  if (!packageJsonPath) {
    if (fallbackToCwd) {
      return process.cwd();
    }
    throw new Error("Unable to find project root (no package.json found)");
  }
  return dirname(packageJsonPath);
}

// src/filesystem/exists.ts
import { stat } from "node:fs/promises";
async function exists(path) {
  try {
    await stat(path);
    return true;
  } catch {
    return false;
  }
}

// src/filesystem/mono-repo.ts
import { readFile } from "node:fs/promises";
import { dirname as dirname2, join as join2 } from "node:path";
import { findUp as findUp2 } from "find-up";
import { glob } from "glob";
async function findMonoRepoRoot(startDir) {
  const lockFilePath = await findUp2(["package-lock.json", "yarn.lock", "pnpm-lock.yaml", "bun.lockb", "bun.lock"], {
    cwd: startDir
  });
  if (lockFilePath) {
    const packageJsonPath = join2(dirname2(lockFilePath), "package.json");
    const hasWorkSpaces = await packageJsonHasWorkspaces(packageJsonPath);
    return hasWorkSpaces ? dirname2(lockFilePath) : null;
  }
  let currentDir = startDir;
  while (currentDir !== "/") {
    const packageJsonPath = join2(currentDir, "package.json");
    if (await packageJsonHasWorkspaces(packageJsonPath)) {
      return currentDir;
    }
    const parentDir = dirname2(currentDir);
    if (parentDir === currentDir) {
      break;
    }
    currentDir = parentDir;
  }
  return null;
}
async function findMonoRepoPackages(projectDir) {
  try {
    const monoRepoRoot = await findMonoRepoRoot(projectDir);
    if (!monoRepoRoot) {
      return [projectDir];
    }
    const packageJsonPath = join2(monoRepoRoot, "package.json");
    const packageJson = tryParseJson(await readFile(packageJsonPath, "utf-8"));
    const workspaces = packageJson?.workspaces ?? [];
    const packagePaths = await Promise.all(
      workspaces.map(async (workspace) => {
        const matches = await glob(join2(monoRepoRoot, workspace, "package.json"));
        return matches.map((match) => join2(match, ".."));
      })
    );
    const allPaths = packagePaths.flat();
    return allPaths.length === 0 ? [projectDir] : [monoRepoRoot, ...allPaths];
  } catch (error) {
    return [projectDir];
  }
}
async function packageJsonHasWorkspaces(packageJsonPath) {
  if (await exists(packageJsonPath)) {
    const packageJson = tryParseJson(await readFile(packageJsonPath, "utf-8"));
    if (packageJson?.workspaces && Array.isArray(packageJson?.workspaces) && packageJson?.workspaces.length > 0) {
      return true;
    }
  }
  return false;
}

// src/environment/write-env.ts
import { config as config2 } from "@dotenvx/dotenvx";
import { deepmerge } from "deepmerge-ts";
async function writeEnv({
  prod,
  env,
  secrets,
  cwd
}) {
  const projectDir = await projectRoot(true, cwd);
  if (prod) {
    process.env.NODE_ENV = "production";
  }
  const targetDirs = await findMonoRepoPackages(projectDir);
  await Promise.all(
    targetDirs.map(async (dir) => {
      const envFile = join3(
        dir,
        secrets ? `.env${prod ? ".production" : ""}.local` : `.env${prod ? ".production" : ""}`
      );
      let { parsed: currentEnv } = await exists(envFile) ? config2({
        path: envFile,
        logLevel: "error",
        quiet: true
      }) : { parsed: {} };
      if (!currentEnv) {
        currentEnv = {};
      }
      const mergedEnv = deepmerge(pruneCurrentEnv(currentEnv, env), env);
      await writeFile(envFile, stringify(mergedEnv));
    })
  );
}
var quote = /[\s"'#]/;
function stringifyPair([key, val]) {
  if (val === void 0) {
    return void 0;
  }
  if (val === null) {
    return `${key}=""`;
  }
  const type = typeof val;
  if (type === "string") {
    return `${key}=${quote.test(val) ? JSON.stringify(val) : val}`;
  }
  if (type === "boolean" || type === "number") {
    return `${key}=${val}`;
  }
  if (type === "object") {
    return `${key}=${JSON.stringify(val)}`;
  }
  throw new Error(`Unsupported type for key "${key}": ${type}`);
}
function stringify(obj) {
  return Object.entries(obj).sort(([a], [b]) => a.localeCompare(b)).map(stringifyPair).filter((value) => value !== void 0).join("\n");
}
function pruneCurrentEnv(currentEnv, env) {
  const dotEnvKeys = Object.keys(DotEnvSchema.shape);
  return Object.fromEntries(
    Object.entries(currentEnv).filter(([key]) => {
      if (dotEnvKeys.includes(key) && !env[key]) {
        return false;
      }
      return true;
    })
  );
}
export {
  loadEnv,
  writeEnv
};
//# sourceMappingURL=environment.mjs.map